@@ -437,7 +437,7 @@ Mandatory arguments:
   -x: expand result, do additional lookups if data is truncated
   -f: force ipv4 (-f 4) or ipv6 (-f 6) connection, else use what your system picks
       Note: option added to force mode if you experience DNS/connect problems
-  -r: Use terminal colors
+  -l: Use terminal colors
 
  Format for output of the result:
 
